@@ -1,6 +1,6 @@
 import sys
-from PyQt5.QtWidgets import QWidget, QMessageBox, QApplication, QLabel # type: ignore
-from PyQt5.QtGui import QIcon, QPixmap # type: ignore
+from PyQt6.QtWidgets import QWidget, QApplication, QLabel # type: ignore
+from PyQt6.QtGui import QPixmap # type: ignore
 
 from typing import *
 
@@ -27,13 +27,13 @@ class ShowImage(QWidget): # type: ignore
         self.show()
 
     def mousePressEvent(self, e: Any) -> None:
-        self.click_x = e.x()
-        self.click_y = e.y()
+        self.click_x = e.position().x()
+        self.click_y = e.position().y()
         print(f"x: {self.click_x},  y: {self.click_y}")
         self.close()
 
 def show_image(file_name: str, width: int, height: int) -> Tuple[int, int]:
     app = QApplication(sys.argv)
     ex = ShowImage(file_name, width, height)
-    app.exec_()
+    app.exec()
     return (ex.click_x, ex.click_y)
\ No newline at end of file
