@@ -17,15 +17,22 @@ class Configuration:
         self.retina: bool = False
         self.mouse_x: int = 0
         self.mouse_y: int = 0
+        self.next_page_key: str = ""
         self.resize_ratio: float = 1
         self.convert_to_bw = True
-        self.jsonize = ["work_dir", "x1", "y1", "x2", "y2", "mouse_x", "mouse_y", "resize_ratio", "convert_to_bw", "retina", "sleep"]
+        self.total_pages = 0
+        self.dir_opener = "open"
+        self.jsonize = ["work_dir", "x1", "y1", "x2", "y2", "mouse_x", "mouse_y", "resize_ratio", "convert_to_bw", "retina", "sleep", "total_pages", "dir_opener", "next_page_key"]
         if self.work_dir != ".":
             os.makedirs(self.work_dir)
 
         home_dir = str(pathlib.Path.home()) or os.environ.get("HOME") or os.environ.get("HOMEPATH") or ""
         self.cfg_file = path.join(home_dir, ".screenshots.json")
 
+    def ratio(self) -> str:
+        try: return f"1:{(self.y2 - self.y1)/(self.x2 - self.x1)}"
+        except: return "???"
+
     def path(self, filename: str) -> str:
         if not self.work_dir:
             return filename
